/*
    creates a tag that is shown / hidden, depending on the visibility rules.
    if not configured dynamically, it looks like this:
    <feature name="featurename" variant="variantname" data="data">content </feature>

    Parameter: (config)
    - config.tagname: name of the tag. Default: "feature"
    - nameAttributeName: Name of the Name-Attribute: default: "name"
    - variantAttributeName: Name of the Variant-Attribute: default: "variant"
*/

function htmlplugin(config = {}) {
    const tagname = config.tagname || 'feature';
    const nameAttributeName = config.nameAttributeName || 'name';
    const variantAttributeName = config.variantAttributeName || 'variant';
    const dataAttributeName = config.dataAttributeName || 'data';

    return function (api) {
        var featureTags = window.document.querySelectorAll(tagname);
        featureTags.forEach(tag => { tag.style.display = 'none' });

        api.on('visibilityrule', function (event) {
            var selector = `feature[${nameAttributeName}="${event.name}"]`;
            if (event.variant) selector += `[${variantAttributeName}="${event.variant}"]`;
            var elements = document.querySelectorAll(selector);
            elements.forEach(elem => { elem.style.display = event.result ? 'block' : none });
        })

        return { name: 'htmlplugin' };
    }
}
if(typeof window !== 'undefined')
    window.htmlplugin = htmlplugin;

if(typeof module !== 'undefined')
    module.exports = htmlplugin;